@@ -193,7 +193,7 @@ def testing():
     return bool("TESTING", False)
 
 
-def database_folder():
+def database_folder() -> str:
     path = string("DATABASE_FOLDER", f"../sqlite/")
     if testing():
         path += "test/"
