@@ -19,7 +19,7 @@ from openmodule.threading import get_thread_wrapper
 
 
 class OpenModuleCore(threading.Thread):
-    database = None
+    database: Optional[Database] = None
 
     def __init__(self, context, config):
         super().__init__(target=get_thread_wrapper(self._run))
@@ -37,7 +37,7 @@ class OpenModuleCore(threading.Thread):
         self.health = Healthz(self)
         self.alerts = AlertHandler(self)
         self.messages.register_handler(b"healthz", HealthPingMessage, self.health.process_message,
-                                       filter={"type": "ping"})
+                                       filter={"type": "ping"}, register_schema=False)
 
     def _subscribe(self, topic: bytes):
         with self.sub_lock:
@@ -126,7 +126,7 @@ def shutdown_openmodule():
     global _core_thread
     assert _core_thread, "core thread is not running, did you call init_openmodule(...)?"
 
-    current_cure = _core_thread
+    current_core: OpenModuleCore = _core_thread
     _core_thread = None
 
     shutdown_done = threading.Event()
@@ -135,14 +135,14 @@ def shutdown_openmodule():
         if not shutdown_done.wait(timeout=1):
             os._exit(99)
 
-    if not (current_cure.config.TESTING or current_cure.config.DEBUG):
+    if not (current_core.config.TESTING or current_core.config.DEBUG):
         last_will_thread = threading.Thread(target=last_will)
         last_will_thread.setDaemon(True)
         last_will_thread.start()
 
-    if current_cure.database:
-        current_cure.database.shutdown()
+    if current_core.database:
+        current_core.database.shutdown()
 
-    current_cure.context.term()
-    current_cure.join()
+    current_core.context.term()
+    current_core.join()
     shutdown_done.set()
