@@ -1,12 +1,13 @@
-from datetime import datetime
 from enum import Enum
+
+from datetime import datetime
+from dateutil import rrule, tz
+from dateutil.utils import default_tzinfo
+from pydantic import validator, Field
 from typing import List, Optional
 
-from dateutil import rrule
-
 from openmodule import config
-from pydantic import validator
-from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway
+from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway, timezone_validator
 
 
 class Medium(str, Enum):
@@ -30,6 +31,9 @@ class Category(str, Enum):
 
 
 class AccessRequest(OpenModuleModel):
+    """
+    The AccessRequest Model
+    """
     name: str
     gateway: Optional[Gateway] = None
     medium_type: Medium
@@ -37,42 +41,58 @@ class AccessRequest(OpenModuleModel):
 
 
 def check_recurrence(cls, recurrence, values, **kwargs):
-    if recurrence == "":
-        return recurrence
-    if recurrence:
+    if recurrence is not None:
         if not values.get("duration"):
-            raise ValueError("set duration when using recurrence")
-        if not values.get("start"):
-            raise ValueError("set start timestamp when using recurrence")
-    try:
-        rrule.rrulestr(recurrence)
-    except Exception as e:
-        raise ValueError(f"recurrence is not valid {e}")
-    return recurrence
+            raise ValueError("set a duration when using recurrence")
+
+        try:
+            if "DTSTART" not in recurrence:
+                raise ValueError("recurrence must contain a DTSTART field")
+
+            if "\n" not in recurrence:
+                raise ValueError("DTSTART must be separated by a newline '\\n' character")
+
+            rrule.rrulestr(recurrence)
+        except Exception as e:
+            raise ValueError(f"recurrence is not valid '{e}'") from None
+        return recurrence
+    else:
+        return None
 
 
 class Access(OpenModuleModel):
     category: Category
     start: datetime
     end: Optional[datetime] = None
-    duration: Optional[int]
+    duration: Optional[int] = Field(description="duration in seconds, starting with the start time of the "
+                                                "recurrence. Required if recurrence is set.")
     recurrence: Optional[str]
     zone: Optional[str]
     occupant_check: bool = False
-    infos: Optional[dict]
+    infos: Optional[dict] = {}
     user: str
 
     _check_recurrence = validator("recurrence", allow_reuse=True)(check_recurrence)
+    _check_start = timezone_validator("start")
+    _check_end = timezone_validator("end")
 
     def dict(self, **kwargs):
         data = super().dict(**kwargs)
-        if "start" in data:
-            data["start"] = data["start"].timestamp()
-        if "end" in data:
-            if data["end"] is not None:
-                data["end"] = data["end"].timestamp()
+        data["start"] = data["start"].timestamp()
+        if data.get("end") is not None:
+            data["end"] = data["end"].timestamp()
         return data
 
+    def is_valid_at(self, dt, timezone):
+        dt = default_tzinfo(dt, tz.UTC)
+        if self.recurrence:
+            assert False, "recurrent accesses are not yet supported"
+        else:
+            if self.end:
+                return self.start <= dt <= self.end
+            else:
+                return self.start <= dt
+
 
 class MediumAccesses(OpenModuleModel):
     accesses: List[Access]
