@@ -1,8 +1,7 @@
 import logging
 import threading
 from collections import namedtuple
-from typing import Callable, Any, Dict, Optional, Type
-from uuid import UUID
+from typing import Callable, Dict, Optional, Type
 
 import zmq
 from pydantic import ValidationError, BaseModel
@@ -12,13 +11,12 @@ from openmodule.messaging import get_sub_socket, get_pub_socket, receive_message
 from openmodule.models.rpc import RPCResponse, RPCRequest
 from openmodule.rpc.common import channel_to_request_topic, channel_to_response_topic
 from openmodule.threading import get_thread_wrapper
+from openmodule.utils.schema import Schema
 
 CallbackEntry = namedtuple("CallbackEntry", ["timestamp", "result"])
 HandlerEntry = namedtuple("HandlerEntry", ["request_class", "response_class", "handler"])
 
 
-
-
 def gateway_filter(gate=None, direction=None):
     def _filter(request, message, handler):
         gateway = request.get("gateway")
@@ -70,14 +68,17 @@ class RPCServer(object):
             self.thread.join(timeout=timeout)
 
     def register_handler(self, channel: str, type: str, request_class: Type[BaseModel], response_class: Type[BaseModel],
-                         handler: Callable):
+                         handler: Callable, register_schema=True):
         """
         :param channel: rpc channel you want to subscribe to, patterns/wildcards are not supported
         :param type: the request type
+        :param request_class: Class definition of the request
+        :param response_class: Class definition of the response
         :param handler: request handler of the form (request:dict, meta:dict) -> any
                         if the handler returns a dict which contains the key "status",
                         then the value of "status" will be used as the rpc response status.
                         There are no other reserved keys except "status".
+        :param register_schema: register the schema and models of this rpc during testing to create an automatic doc
         """
         if (channel, type) in self.handlers:
             raise ValueError(f"handler for {channel}:{type} is already registered")
@@ -85,6 +86,8 @@ class RPCServer(object):
         self.log.debug("register handler {}:{} -> {}".format(channel, type, handler))
         self.sub.subscribe(channel_to_request_topic(channel.encode("ascii")))
         self.handlers[(channel, type)] = HandlerEntry(request_class, response_class, handler)
+        if register_schema:
+            Schema.save_rpc(channel, type, request_class, response_class, handler)
 
     def _channel_from_topic(self, topic: bytes) -> str:
         return topic.split(b"-", 2)[-1].decode("ascii")
