@@ -1,7 +1,6 @@
 import logging
 from typing import Optional, Dict, Union
 
-
 from openmodule.dispatcher import EventListener, MessageDispatcher
 from openmodule.models.base import Gateway
 from openmodule.models.presence import PresenceBaseMessage, PresenceBackwardMessage, PresenceForwardMessage, \
@@ -61,6 +60,10 @@ class PresenceListener:
         return (self.gate is None) or (message.gateway.gate == self.gate)
 
     def _on_backward(self, message: PresenceBackwardMessage):
+        """
+        This handler forwards presence backward  messages to the registered calls in the presence listener
+        """
+
         if not self._gate_matches(message):
             return
         vehicle = vehicle_from_presence_message(message)
@@ -68,6 +71,9 @@ class PresenceListener:
         self.on_backward(vehicle, message.gateway)
 
     def _on_forward(self, message: PresenceForwardMessage):
+        """
+        This handler forwards presence forward messages to the registered calls in the presence listener
+        """
         if not self._gate_matches(message):
             return
         vehicle = vehicle_from_presence_message(message)
@@ -75,6 +81,11 @@ class PresenceListener:
         self.on_forward(vehicle, message.gateway)
 
     def _on_leave(self, message: PresenceLeaveMessage):
+        """
+        This handler forwards presence leave messages to the registered calls in the presence listener
+        and clears the present vehicle
+        """
+
         if not self._gate_matches(message):
             return
         leaving_vehicle = vehicle_from_presence_message(message)
@@ -84,10 +95,8 @@ class PresenceListener:
             if present_vehicle.id != leaving_vehicle.id:
                 self.log.error("A vehicle left with a different vehicle id than the present one. Tracking is "
                                "inconsistent. We are fake-leaving the currently present vehicle, to ensure consistent "
-                               "states.", extra={
-                    "present_vehicle": str(present_vehicle),
-                    "leaving_vehicle": str(leaving_vehicle)
-                })
+                               "states.", extra={"present_vehicle": str(present_vehicle),
+                                                 "leaving_vehicle": str(leaving_vehicle)})
             self.present_vehicles.pop(message.gateway.gate, None)
             self.on_leave(leaving_vehicle, message.gateway)
         else:
@@ -96,6 +105,11 @@ class PresenceListener:
                            extra={"leaving_vehicle": str(leaving_vehicle)})
 
     def _on_enter(self, message: PresenceEnterMessage):
+        """
+        This handler forwards presence enter messages to the registered calls in the presence listener
+        and sets the present vehicle
+        """
+
         if not self._gate_matches(message):
             return
         new_vehicle = vehicle_from_presence_message(message)
@@ -104,23 +118,23 @@ class PresenceListener:
         if present_vehicle:
             self.log.error("A new vehicle entered while one was still present. Tracking is inconsistent. "
                            "A leave will be faked, to ensure consistent states.",
-                           extra={
-                               "present_vehicle": str(present_vehicle),
-                               "new_vehicle": str(new_vehicle)
-                           })
+                           extra={"present_vehicle": str(present_vehicle),
+                                  "new_vehicle": str(new_vehicle)})
             self.present_vehicles.pop(message.gateway.gate, None)
             self.on_leave(present_vehicle, message.gateway)
+
         self.present_vehicles[message.gateway.gate] = new_vehicle
         self.on_enter(new_vehicle, message.gateway)
 
     def _on_change(self, message: PresenceChangeMessage):
+        """
+        This handler forwards presence change messages to the registered calls in the presence listener
+        and changes the present vehicle
+        """
+
         if not self._gate_matches(message):
             return
         vehicle = vehicle_from_presence_message(message)
-
-        if message.change_vehicle_id:
-            self.log.info(f"Changing vehicle ID from {self.present_vehicles[message.gateway.gate].id} to "
-                          f"{message.vehicle_id}")
-            self.present_vehicles[message.gateway.gate] = vehicle
+        self.present_vehicles[message.gateway.gate] = vehicle
         self.log.debug("presence change: %s", vehicle)
         self.on_change(vehicle, message.gateway)
