@@ -4,14 +4,18 @@ import threading
 import time
 from typing import Callable
 
+from openmodule.utils.schema import Schema
+
 
 class InterruptTestMixin:
     """
     Helper class for testing interrupts and exceptions in code
     for usage, look at file tests/test_interrupt
     """
-    time = 3
-    timeout = 3
+
+    def tearDown(self):
+        super().tearDown()
+        Schema.to_file()
 
     @classmethod
     def async_raise(cls, thread_obj, exception):
@@ -33,13 +37,13 @@ class InterruptTestMixin:
             ctypes.pythonapi.PyThreadState_SetAsyncExc(target_tid, None)
             raise SystemError("PyThreadState_SetAsyncExc failed")
 
-    def exception_in_function(self, f, exception):
+    def exception_in_function(self, f, exception, *, raise_exception_after: float = 3.0, shutdown_timeout: float = 3.0):
         thread = threading.Thread(target=f, daemon=True)
         thread.start()
-        time.sleep(self.time)
+        time.sleep(raise_exception_after)
         self.async_raise(thread, exception)
         t0 = time.time()
-        while time.time() - t0 < self.timeout:
+        while time.time() - t0 < shutdown_timeout:
             if thread.is_alive():
                 time.sleep(0.5)
             else:
@@ -47,14 +51,13 @@ class InterruptTestMixin:
         self.async_raise(thread, SystemExit)
         raise AssertionError("Thread took to long for shutdown")
 
-    def custom_action_in_function(self, f, action):
+    def custom_action_in_function(self, f, action, *, call_action_after: float = 3.0, shutdown_timeout: float = 3.0):
         thread = threading.Thread(target=f, daemon=True)
         thread.start()
-        time.sleep(self.time)
-        logging.error("asdf")
+        time.sleep(call_action_after)
         action(f)
         t0 = time.time()
-        while time.time() - t0 < self.timeout:
+        while time.time() - t0 < shutdown_timeout:
             if thread.is_alive():
                 time.sleep(0.2)
             else:
