@@ -3,10 +3,10 @@ import time
 from threading import Thread
 from unittest import TestCase
 
-from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
+from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound, DetachedInstanceError
 
 from openmodule.config import database_folder
-from openmodule.database.database import Database, active_databases, database_name
+from openmodule.database.database import Database, active_databases, database_path
 from openmodule.utils.db_helper import update_query, delete_query
 from openmodule_test.database import SQLiteTestMixin
 from openmodule_test.database_models import DatabaseTestModel
@@ -45,6 +45,30 @@ class DatabaseTest(SQLiteTestMixin, TestCase):
             self.assertEqual(2, results.count())
             self.assertEqual(3, db.query(DatabaseTestModel).filter_by(value1=7).count())
 
+    def test_expire_on_commit(self):
+        with self.database as db:
+            model = DatabaseTestModel(value1=1)
+            db.add(model)
+            db.flush()
+            pk = model.id
+
+        # default expire is True
+        with self.database as db:
+            model = db.query(DatabaseTestModel).get(pk)
+        with self.assertRaises(DetachedInstanceError):
+            self.assertEqual(model.value1, 1)
+
+        # default expire also is True when calling database
+        with self.database() as db:
+            model = db.query(DatabaseTestModel).get(pk)
+        with self.assertRaises(DetachedInstanceError):
+            self.assertEqual(model.value1, 1)
+
+        # passing expire_on_commit disables the expire
+        with self.database(expire_on_commit=False) as db:
+            model = db.query(DatabaseTestModel).get(pk)
+        self.assertEqual(model.value1, 1)
+
     def test_delete(self):
         data = [DatabaseTestModel(value1=x % 5, value2=x % 3) for x in range(10)]
         with self.database as db:
@@ -84,11 +108,11 @@ class DatabaseTest(SQLiteTestMixin, TestCase):
 
     def test_database_transaction_is_single_threaded(self):
         """
-        this test starts a second thread, which waits for 0.5s, after that it tries to aquire the database
-        and read the value of an object. The main thread in the meantimes blocks for 2 seconds, and after that
+        this test starts a second thread, which waits for 0.5s, after that it tries to acquire the database
+        and read the value of an object. The main thread in the meantime blocks for 2 seconds, and after that
         writes something to the database. Both threads check that the other is at the expected state.
         The test shows that the transaction is single threaded, and all threads are blocked while
-        a thread has aquired the db
+        a thread has acquired the db
         """
         main_thread_position = ""
         second_thread_position = ""
@@ -159,6 +183,7 @@ class DatabaseTest(SQLiteTestMixin, TestCase):
                 base.one_or_none()
             self.assertEqual(MultipleResultsFound, type(e.exception))
 
+
 class ShutdownTestCase(TestCase):
     alembic_path = "../tests/test_database_data"
 
@@ -166,7 +191,7 @@ class ShutdownTestCase(TestCase):
         return Database(database_folder(), name="shutdown", alembic_path=self.alembic_path)
 
     def check_db_present(self, value):
-        tmp = database_name(database_folder(), "shutdown")
+        tmp = database_path(database_folder(), "shutdown")
         if value:
             self.assertIn(tmp, active_databases.keys())
         else:
@@ -179,18 +204,6 @@ class ShutdownTestCase(TestCase):
         database.shutdown()
         self.check_db_present(False)
 
-        database1 = self.get_database()
-        self.check_db_present(True)
-        del database1
-        self.check_db_present(False)
-
-        def scope():
-            database2 = self.get_database()
-            self.check_db_present(True)
-
-        scope()
-        self.check_db_present(False)
-
     def test_shutdown_while_using(self):
         database = self.get_database()
 
@@ -216,3 +229,25 @@ class ShutdownTestCase(TestCase):
             database.shutdown()
         self.assertIn("already closed", str(e.exception))
         self.check_db_present(False)
+
+
+class MultipleMigrationTest(SQLiteTestMixin, TestCase):
+    """
+    there was an issue, which prevented a database from beeing migrated multiple times in a single process
+    """
+    create_database = False
+    alembic_path = "../tests/test_database_data"
+
+    def test_migrate_1(self):
+        database = Database(self.database_folder, self.database_name, self.alembic_path)
+        with database as db:
+            self.assertEqual(0, db.query(DatabaseTestModel).count())
+        database.shutdown()
+        self.delete_database(database)
+
+    def test_migrate_2(self):
+        database = Database(self.database_folder, self.database_name, self.alembic_path)
+        with database as db:
+            self.assertEqual(0, db.query(DatabaseTestModel).count())
+        database.shutdown()
+        self.delete_database(database)
