@@ -83,10 +83,8 @@ class PresenceTest(BasePresenceTest):
         self.assertEqual(vehicle_0.vehicle_id, self.presence.present_vehicles["gate_in"].id)
 
         vehicle_1 = self.presence_sim.vehicle().lpr("A", "G ARIVO1")
-        with self.assertLogs() as cm:
-            self.presence_sim.change_vehicle_and_id(vehicle_1)
-            self.on_change.wait_for_call()
-        self.assertIn("Changing vehicle ID", str(cm.output[0]))
+        self.presence_sim.change_vehicle_and_id(vehicle_1)
+        self.on_change.wait_for_call()
 
         self.assertEqual(vehicle_1.vehicle_id, self.presence.present_vehicles["gate_in"].id)
 
@@ -95,6 +93,17 @@ class PresenceTest(BasePresenceTest):
 
         self.assertIsNone(self.presence.present_vehicles.get("gate_in"))
 
+    def test_lpr_change(self):
+        vehicle_0 = self.presence_sim.vehicle().lpr("A", "GARIVO1")
+        self.presence_sim.enter(vehicle_0)
+        self.on_enter.wait_for_call()
+        self.assertEqual("GARIVO1", self.presence.present_vehicles["gate_in"].lpr.id)
+
+        vehicle_0.lpr("A", "GARIVO2")
+        self.presence_sim.change(vehicle_0)
+        self.on_change.wait_for_call()
+        self.assertEqual("GARIVO2", self.presence.present_vehicles["gate_in"].lpr.id)
+
     def test_normal(self):
         self.presence_sim.enter(self.presence_sim.vehicle().lpr("A", "G ARIVO1"))
         self.on_enter.wait_for_call()
@@ -121,8 +130,15 @@ class PresenceTest(BasePresenceTest):
         self.on_change.wait_for_call()
         self.on_change.reset_call_count()
 
-        with self.assertRaises(AssertionError):
-            self.presence_sim.change_vehicle_and_id(vehicle_changed)
+
+class PresenceTestUtilsTest(BasePresenceTest):
+    def test_vehicle_id_change_is_enforced(self):
+        vehicle = self.presence_sim.vehicle().lpr("A", "G ARIVO1")
+        self.presence_sim.enter(vehicle)
+
+        with self.assertRaises(AssertionError) as e:
+            self.presence_sim.change_vehicle_and_id(vehicle)
+        self.assertIn("vehicle id must change", str(e.exception))
 
         self.presence_sim.change_vehicle_and_id(self.presence_sim.vehicle().lpr("A", "G ARIVO1"))
         self.on_change.wait_for_call()
